////////////////////////////////////////////////////////////////////////
// $Id: EVD.cxx,v 1.2 2010/11/10 22:49:25 p-novaart Exp $
//
// EVD event display module for Argoneut
//
// brebel@fnal.gov
// msoderbe@syr.edu
//
//
////////////////////////////////////////////////////////////////////////
#ifndef ARGONEUTEVD_H
#define ARGONEUTEVD_H
#ifndef __CINT__

extern "C" {
#include <sys/types.h>
#include <sys/stat.h>
}

//LArSoft includes
#include "nutools/EventDisplayBase/DisplayWindow.h"
#include "ArgoneutEventDisplay/DisplayArgoneutView.h"
#include "ArgoneutEventDisplay/ArgoneutOrtho3DView.h"
#include "ArgoneutEventDisplay/ArgoneutTWQProjectionView.h"
#include "lareventdisplay/EventDisplay/Display3DView.h"
#include "lareventdisplay/EventDisplay/Ortho3DView.h"
#include "lareventdisplay/EventDisplay/CalorView.h"

// Framework includes
#include "art/Framework/Core/ModuleMacros.h"
#include "art/Framework/Principal/Event.h"
#include "fhiclcpp/ParameterSet.h"
#include "art/Framework/Principal/Handle.h"
#include "art/Framework/Services/Registry/ServiceHandle.h"
#include "art/Framework/Services/Optional/TFileService.h"
#include "art/Framework/Services/Optional/TFileDirectory.h"
#include "messagefacility/MessageLogger/MessageLogger.h"
#include "art/Framework/Core/EDAnalyzer.h"

#include <string>
#include "TH1D.h"

/// The Event Display
namespace argoevd{

  /// a class for transporting photons in a roughly realistic way
  class ArgoneutEVD : public art::EDAnalyzer 
  {
   public:
     explicit ArgoneutEVD(fhicl::ParameterSet const &pset);
     virtual ~ArgoneutEVD();

     void analyze(art::Event const& evt);
     void beginJob();

   };
}


// Builder for the TWQProjectionView canvas
static evdb::Canvas* mk_twqprojectionview_canvas(TGMainFrame* mf)
{
   return new argoevd::ArgoneutTWQProjectionView(mf);
}

// Builder for the Display3D view
static evdb::Canvas* mk_display3d_canvas(TGMainFrame* mf)
{
   return new evd::Display3DView(mf);
}

// Builder for the Ortho view
static evdb::Canvas* mk_ortho3d_canvas(TGMainFrame* mf)
{
   return new evd::Ortho3DView(mf);
}

// Builder for the Calor view
static evdb::Canvas* mk_calor_canvas(TGMainFrame* mf)
{
   return new evd::CalorView(mf);
}

// Builder for the ArgoNeuT 3D view
static evdb::Canvas* mk_displayargoneut_canvas(TGMainFrame* mf)
{
   return new argoevd::DisplayArgoneutView(mf);
}

// Builder for the ArgoNeuT 3D view
static evdb::Canvas* mk_argoneutortho3d_canvas(TGMainFrame* mf)
{
   return new argoevd::ArgoneutOrtho3DView(mf);
}

// // Builder for the MCTruth view
// static evdb::ObjListCanvas* mk_mctrue_canvas(TGMainFrame* mf)
// {
//   return new evd::MCTrueView(mf);
// }


namespace argoevd{

   //----------------------------------------------------
   ArgoneutEVD::ArgoneutEVD(fhicl::ParameterSet const& pset):
   EDAnalyzer(pset)
   {

   }

   //----------------------------------------------------
   ArgoneutEVD::~ArgoneutEVD()
   {
   }

   //----------------------------------------------------
   void ArgoneutEVD::beginJob()
   {
      // Register the list of windows used by the event display
      evdb::DisplayWindow::Register("Time vs Wire, Charge View",
                                    "Time vs Wire, Charge View",
                                    700,
                                    700,
                                    mk_twqprojectionview_canvas);

      evdb::DisplayWindow::Register("Display3D",
                                    "Display3D",
                                    700,
                                    700,
                                    mk_display3d_canvas);

      evdb::DisplayWindow::Register("Ortho3D",
                                    "Ortho3D",
                                    700,
                                    700,
                                    mk_ortho3d_canvas);


      evdb::DisplayWindow::Register("DisplayArgoneut",
                                    "DisplayArgoneut",
                                    700,
                                    700,
                                    mk_displayargoneut_canvas);

      evdb::DisplayWindow::Register("Calorimetry",
                                    "Calorimetry",
                                    700,
                                    700,
                                    mk_calor_canvas);

      evdb::DisplayWindow::Register("ArgoneutOrtho3D",
                                    "ArgoneutOrtho3D",
                                    700,
                                    700,
                                    mk_argoneutortho3d_canvas);
    
//     evdb::ListWindow::Register("MC Particle List",
// 			       "MC Particle List",
// 			       400,
// 			       800,
// 			       mk_mctrue_canvas);
 
      // Open up the main display window and run
      evdb::DisplayWindow::OpenWindow(0);

   }

   //----------------------------------------------------
   void ArgoneutEVD::analyze(const art::Event& evt)
   {
   }

}//namespace

namespace argoevd {

  DEFINE_ART_MODULE(ArgoneutEVD)

} // namespace argoevd
////////////////////////////////////////////////////////////////////////


#endif // __CINT__
#endif // EVD
////////////////////////////////////////////////////////////////////////
